@@ -8,17 +8,6 @@
 | Revisions       | None         |
 +-----------------+--------------+
 """
-try:
-    from .store2bigquery import Store2Bigquery
-except ModuleNotFoundError:
-    pass
-
-try:
-    from .store2omnisci import Store2Omnisci
-except ModuleNotFoundError:
-    pass
-
-try:
-    from .store2sql import Store2Sql
-except ModuleNotFoundError:
-    pass
+from .store2bigquery import Store2Bigquery
+from .store2omnisci import Store2Omnisci
+from .store2sql import Store2Sql
